@@ -1,7 +1,7 @@
 package Parallel::ForkManager;
 our $AUTHORITY = 'cpan:DLUX';
 # ABSTRACT:  A simple parallel processing fork manager
-$Parallel::ForkManager::VERSION = '1.16';
+$Parallel::ForkManager::VERSION = '1.18';
 use POSIX ":sys_wait_h";
 use Storable qw(store retrieve);
 use File::Spec;
@@ -114,7 +114,7 @@ sub wait_one_child {
 
     # retrieve child data structure, if any
     my $retrieved = undef;
-    my $storable_tempfile = File::Spec->catfile($s->{tempdir}, 'Parallel-ForkManager-' . $$ . '-' . $kid . '.txt');
+    my $storable_tempfile = File::Spec->catfile($s->{tempdir}, 'Parallel-ForkManager-' . $s->{parent_pid} . '-' . $kid . '.txt');
     if (-e $storable_tempfile) {  # child has option of not storing anything, so we need to see if it did or not
       $retrieved = eval { return &retrieve($storable_tempfile); };
 
@@ -289,7 +289,7 @@ Parallel::ForkManager - A simple parallel processing fork manager
 
 =head1 VERSION
 
-version 1.16
+version 1.18
 
 =head1 SYNOPSIS
 
